summaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-xmpp-utils.h
diff options
context:
space:
mode:
Diffstat (limited to 'epan/dissectors/packet-xmpp-utils.h')
-rw-r--r--epan/dissectors/packet-xmpp-utils.h86
1 files changed, 43 insertions, 43 deletions
diff --git a/epan/dissectors/packet-xmpp-utils.h b/epan/dissectors/packet-xmpp-utils.h
index cf54f9f5..7de1bb41 100644
--- a/epan/dissectors/packet-xmpp-utils.h
+++ b/epan/dissectors/packet-xmpp-utils.h
@@ -22,32 +22,32 @@ elem->data?elem->data->value:""
typedef struct _xmpp_array_t
{
- gpointer data;
- gint length;
+ void *data;
+ int length;
} xmpp_array_t;
typedef struct _xmpp_attr_t{
- const gchar *value;
- const gchar *name;
- gint offset;
- gint length;
+ const char *value;
+ const char *name;
+ int offset;
+ int length;
- gboolean was_read;
+ bool was_read;
} xmpp_attr_t;
typedef struct _xmpp_data_t{
- gchar *value;
+ char *value;
- gint offset;
- gint length;
+ int offset;
+ int length;
} xmpp_data_t;
typedef struct _xmpp_element_t{
- gchar* name;
+ char* name;
/*abbreviation that apprears before tag name (<nos:x .../>)
if abbrev doesn't appear then NULL*/
- gchar* default_ns_abbrev;
+ char* default_ns_abbrev;
/*pair of namespace abbrev and namespace*/
GHashTable *namespaces;
@@ -55,27 +55,27 @@ typedef struct _xmpp_element_t{
GList *elements;
xmpp_data_t *data;
- gint offset;
- gint length;
+ int offset;
+ int length;
- gboolean was_read;
+ bool was_read;
} xmpp_element_t;
/*informations about attributes that are displayed in proto tree*/
typedef struct _xmpp_attr_info{
- const gchar *name;
- const gint *phf;
- gboolean is_required;
- gboolean in_short_list;
+ const char *name;
+ const int *phf;
+ bool is_required;
+ bool in_short_list;
/*function validates this attribute
it may impose other restrictions (e.g. validating atribut's name, ...)*/
- void (*val_func)(packet_info *pinfo, proto_item *item, const gchar *name, const gchar *value, gconstpointer data);
- gpointer data;
+ void (*val_func)(packet_info *pinfo, proto_item *item, const char *name, const char *value, const void *data);
+ void *data;
} xmpp_attr_info;
typedef struct _xmpp_attr_info_ext{
- const gchar* ns;
+ const char* ns;
xmpp_attr_info info;
} xmpp_attr_info_ext;
@@ -94,7 +94,7 @@ typedef enum _xmpp_elem_info_occurrence
/*informations about elements that are displayed in proto tree*/
typedef struct _xmpp_elem_info{
xmpp_elem_info_type type;
- gconstpointer data;
+ const void *data;
/*function that displays element in tree*/
void (*elem_func)(proto_tree* tree, tvbuff_t* tvb, packet_info* pinfo, xmpp_element_t* element);
xmpp_elem_info_occurrence occurrence;
@@ -105,15 +105,15 @@ typedef struct _xmpp_conv_info_t {
wmem_tree_t *jingle_sessions;
wmem_tree_t *ibb_sessions;
wmem_tree_t *gtalk_sessions;
- guint32 ssl_start;
+ uint32_t ssl_start;
} xmpp_conv_info_t;
/** Struct conatins frame numbers (request frame(IQ set/get) and
* response frame(IQ result/error)).
*/
typedef struct _xmpp_reqresp_transaction_t {
- guint32 req_frame;
- guint32 resp_frame;
+ uint32_t req_frame;
+ uint32_t resp_frame;
} xmpp_transaction_t;
/** Function that is responsibe for request/response tracking in IQ packets.
@@ -149,7 +149,7 @@ extern void xmpp_unknown(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo, xm
* ELEMENT_NAME: CDATA
* ELEMENT_NAME = element->name, if element is empty CDATA = "(empty)"
*/
-extern void xmpp_cdata(proto_tree *tree, tvbuff_t *tvb, xmpp_element_t *element, gint hf);
+extern void xmpp_cdata(proto_tree *tree, tvbuff_t *tvb, xmpp_element_t *element, int hf);
/** Function is similar to xmpp_cdata. But it display items only as a text and it is
* compatibile with function display_elems
@@ -166,29 +166,29 @@ extern xmpp_element_t* xmpp_xml_frame_to_element_t(packet_info *pinfo, xml_frame
extern void xmpp_element_t_tree_free(xmpp_element_t *root);
/** Allocs ephemeral memory for xmpp_array_t struct.*/
-extern xmpp_array_t* xmpp_ep_init_array_t(wmem_allocator_t *pool, const gchar** array, gint len);
+extern xmpp_array_t* xmpp_ep_init_array_t(wmem_allocator_t *pool, const char** array, int len);
/*Allocs ephemeral memory for xmpp_attr_t struct*/
-extern xmpp_attr_t* xmpp_ep_init_attr_t(wmem_allocator_t *pool, const gchar *value, gint offset, gint length);
+extern xmpp_attr_t* xmpp_ep_init_attr_t(wmem_allocator_t *pool, const char *value, int offset, int length);
/** steal_*
* Functions searches and marks as read found elements.
* If element is set as read, it is invisible for these functions.*/
-extern xmpp_element_t* xmpp_steal_element_by_name(xmpp_element_t *packet, const gchar *name);
-extern xmpp_element_t* xmpp_steal_element_by_names(xmpp_element_t *packet, const gchar **names, gint names_len);
-extern xmpp_element_t* xmpp_steal_element_by_attr(xmpp_element_t *packet, const gchar *attr_name, const gchar *attr_value);
-extern xmpp_element_t* xmpp_steal_element_by_name_and_attr(xmpp_element_t *packet, const gchar *name, const gchar *attr_name, const gchar *attr_value);
+extern xmpp_element_t* xmpp_steal_element_by_name(xmpp_element_t *packet, const char *name);
+extern xmpp_element_t* xmpp_steal_element_by_names(xmpp_element_t *packet, const char **names, int names_len);
+extern xmpp_element_t* xmpp_steal_element_by_attr(xmpp_element_t *packet, const char *attr_name, const char *attr_value);
+extern xmpp_element_t* xmpp_steal_element_by_name_and_attr(xmpp_element_t *packet, const char *name, const char *attr_name, const char *attr_value);
/*Returns first child in element*/
extern xmpp_element_t* xmpp_get_first_element(xmpp_element_t *packet);
/*Converts element to string. Returns memory allocated from the given pool.*/
-extern gchar* xmpp_element_to_string(wmem_allocator_t *pool, tvbuff_t *tvb, xmpp_element_t *element);
+extern char* xmpp_element_to_string(wmem_allocator_t *pool, tvbuff_t *tvb, xmpp_element_t *element);
/* Returns attribute by name and set as read. If attrib is set as read, it may be found
* one more time, but it is invisible for function xmpp_unknown_attrib*/
-extern xmpp_attr_t* xmpp_get_attr(xmpp_element_t *element, const gchar* attr_name);
+extern xmpp_attr_t* xmpp_get_attr(xmpp_element_t *element, const char* attr_name);
/*Function hides first element in tree.*/
extern void xmpp_proto_tree_hide_first_child(proto_tree *tree);
@@ -197,10 +197,10 @@ extern void xmpp_proto_tree_hide_first_child(proto_tree *tree);
extern void xmpp_proto_tree_show_first_child(proto_tree *tree);
/*Function returns item as text. Memory is allocated from the given pool.*/
-extern gchar* proto_item_get_text(wmem_allocator_t *pool, proto_item *item);
+extern char* proto_item_get_text(wmem_allocator_t *pool, proto_item *item);
/*Function returns struct that contains 3 strings. It is used to build xmpp_attr_info struct.*/
-extern gpointer xmpp_name_attr_struct(wmem_allocator_t *pool, const gchar *name, const gchar *attr_name, const gchar *attr_value);
+extern void *xmpp_name_attr_struct(wmem_allocator_t *pool, const char *name, const char *attr_name, const char *attr_value);
/** Function displays attributes from element in way described in attrs.
* Elements that doesn't exist in attrs are displayed as text.
@@ -210,7 +210,7 @@ extern gpointer xmpp_name_attr_struct(wmem_allocator_t *pool, const gchar *name,
* - val_func - validate function
* - data - data passes to the val_func
*/
-extern void xmpp_display_attrs(proto_tree *tree, xmpp_element_t *element, packet_info *pinfo, tvbuff_t *tvb, const xmpp_attr_info *attrs, guint n);
+extern void xmpp_display_attrs(proto_tree *tree, xmpp_element_t *element, packet_info *pinfo, tvbuff_t *tvb, const xmpp_attr_info *attrs, unsigned n);
/** Function does the same as shown above. It takes attrs(XMPP_ATTR_INFO_EXT) argument
* that contains XMPP_ATTR_INFO struct and string with namespace. It is used when packet
@@ -224,25 +224,25 @@ extern void xmpp_display_attrs(proto_tree *tree, xmpp_element_t *element, packet
* </auth>
* @endcode
*/
-extern void xmpp_display_attrs_ext(proto_tree *tree, xmpp_element_t *element, packet_info *pinfo, tvbuff_t *tvb, const xmpp_attr_info_ext *attrs, guint n);
+extern void xmpp_display_attrs_ext(proto_tree *tree, xmpp_element_t *element, packet_info *pinfo, tvbuff_t *tvb, const xmpp_attr_info_ext *attrs, unsigned n);
/** Displays elements from parent element in a way described in elems(XMPP_ELEM_INFO).
* XMPP_ELEM_INFO describes how to find particular element and what action should be done
* for this element.
* Function calls xmpp_unknown.
*/
-extern void xmpp_display_elems(proto_tree *tree, xmpp_element_t *parent, packet_info *pinfo, tvbuff_t *tvb, xmpp_elem_info *elems, guint n);
+extern void xmpp_display_elems(proto_tree *tree, xmpp_element_t *parent, packet_info *pinfo, tvbuff_t *tvb, xmpp_elem_info *elems, unsigned n);
-/* Validates attribute value. Takes string array(gchar**) in parameter data.
+/* Validates attribute value. Takes string array(char**) in parameter data.
* Is used in XMPP_ATTR_INFO struct.
*/
-extern void xmpp_val_enum_list(packet_info *pinfo, proto_item *item, const gchar *name, const gchar *value, gconstpointer data);
+extern void xmpp_val_enum_list(packet_info *pinfo, proto_item *item, const char *name, const char *value, const void *data);
/** Function changes element to attribute. It searches element by name in parent element,
* next it create attribute using transform_func and inserts it to parent attributes hash table
* using attr_name as key.
*/
-extern void xmpp_change_elem_to_attrib(wmem_allocator_t *pool, const gchar *elem_name, const gchar *attr_name, xmpp_element_t *parent, xmpp_attr_t* (*transform_func)(wmem_allocator_t *pool, xmpp_element_t *element));
+extern void xmpp_change_elem_to_attrib(wmem_allocator_t *pool, const char *elem_name, const char *attr_name, xmpp_element_t *parent, xmpp_attr_t* (*transform_func)(wmem_allocator_t *pool, xmpp_element_t *element));
/** transform_func that creates attribute with element's cdata as value
*/